<?php

/**
 * 收货地区
 */
class omeauto_auto_type_address extends omeauto_auto_type_abstract implements omeauto_auto_type_interface {

    /**
     * 在显示前为模板做一些数据准备工作
     *
     * @param object $tpl
     * @return void
     */
    public function _prepareUI(& $tpl) {

        //编辑状态获取p_region_id、selected_str以及下拉框的area
        if($tpl->pagedata["init"]["content"]){
            //父类是同一个 取一个用来搜索父类region_id
            $regionsObj = app::get('eccommon')->model('regions');
            $region_info = $regionsObj->dump(array("region_id"=>$tpl->pagedata["init"]["content"][0]),"p_region_id");
            //$region_info["p_region_id"]有效就是有父类，否则p_region_id为无效默认会显示所有一级地区列表
            if($region_info["p_region_id"]){
                $tpl->pagedata["p_region_id"] = $region_info["p_region_id"];
            }
            //绑定地区控件显示所需的value
            if($tpl->pagedata["init"]["area"]){
                $tpl->pagedata["omeauto_regions_value"] = $tpl->pagedata["init"]["area"];
            }
            //获取选中的region_id的字符串
            $tpl->pagedata["selected_str"] = implode(",", $tpl->pagedata["init"]["content"]);
        }
        
    }

    /**
     * 检查输入的参数
     *
     * @param Array $params
     * @returm mixed
     */
    public function checkParams($params) {

        if (empty($params['address']) && !is_array($params['address'])) {

            return "你还没有选择收货地址所匹配的区域\n\n请勾选以后再试！！";
        }

        return true;
    }

    /**
     * 生成规则字串
     *
     * @param Array $params
     * @return String
     */
    public function roleToString($params) {

        $rows = kernel::single('eccommon_regions')->getList('local_name', array('region_id' => $params['address']));

        $caption = '';
        foreach ($rows as $row) {

            $caption .= ", " . $row['local_name'];
        }
        $caption = sprintf('收货区域在 %s ', preg_replace('/^,/is', '', $caption));

        $role = array('role' => 'address', 'caption' => $caption, 'content' => $params['address'], 'area' => $params['area']);

        return json_encode($role);
    }

    /**
     * 设置已经创建好的配置内容
     *
     * @param array $params
     * @return void
     */
    public function setRole($params) {
        $this->content = array();
        //转换为字符名称
        if (!empty($params) && is_array($params)) {
            $rows = kernel::single('eccommon_regions')->getListByIds($params);
            foreach ($rows as $row) {
                $this->content[] = $row['local_name'];
            }
        }
    }

    /**
     * 检查订单数据是否符合要求
     *
     * @param omeauto_auto_group_item $item
     * @return boolean
     */
    public function vaild($item) {

        if (!empty($this->content)) {

            foreach ($item->getOrders() as $order) {
                //检查订单类型
                $area = $order['ship_area'];
                                
                //规则支持多级地区 自身area的层级名称数组中任何一个地区与规则的地区一样 视为符合当前的自动规则
                kernel::single('eccommon_regions')->split_area($area);
                if(!array_intersect($area,$this->content)){
                    return false;
                }
            }
            return true;
        } else {

            return false;
        }
    }

    /**
     * 获取地区列表
     *
     * @param Array $regionLists
     * @param Integer $parent
     * @return Array
     */
    private function _getRegions($regionLists, $parent= 0) {

        $ret = array();

        foreach ($regionLists as $row) {

            $path = ereg_replace('^,|,$', '', $row['region_path']);
            $depth = substr_count($path, ',');
            if ($depth == 0) {

                $ret[$path]['caption'] = $row['local_name'];
            } elseif ($depth == 1) {

                $path = split(',', $path);
                $ret[$path[0]]['items'][$path[1]]['caption'] = $row['local_name'];
            } else {

                $path = split(',', $path);
                $ret[$path[0]]['items'][$path[1]]['items'][$path[2]] = $row['local_name'];
            }
        }

        return $ret;
    }

}